@@ -46,6 +46,7 @@ import pathlib
 import tempfile
 import numpy as np
 import scipy.optimize
+import scipy.sparse as sp
 
 import qutip
 from qutip.control import pulseoptim as cpo
@@ -149,6 +150,7 @@ symplectic = _System(system=_sympl_system,
 @pytest.fixture(params=[
     pytest.param(None, id="default propagation"),
     pytest.param({'oper_dtype': qutip.Qobj}, id="Qobj propagation"),
+    pytest.param({'oper_dtype': np.ndarray}, id="ndarray propagation"),
 ])
 def propagation(request):
     return {'dyn_params': request.param}
@@ -198,6 +200,38 @@ class TestOptimization:
         result = _optimize_pulse(system)
         assert result.fid_err < system.kwargs['fid_err_targ']
 
+    def test_sparse_eigen_optimization(self, system, propagation):
+        system = _merge_kwargs(system, {
+            **propagation,
+            "dyn_params": {
+                **(propagation.get("dyn_params") or {}),
+                "sparse_eigen_decomp": True,
+            }
+        })
+        if system.system.dims == [[2], [2]]:
+            with pytest.raises(ValueError, match=(
+                    r"^Single qubit pulse optimization dynamics cannot use"
+                    r" sparse eigenvector decomposition")):
+                _optimize_pulse(system)
+        else:
+            result = _optimize_pulse(system)
+            assert result.fid_err < system.kwargs['fid_err_targ']
+
+    @pytest.mark.parametrize("oper_dtype", [
+        pytest.param(sp.csr_matrix, id="csr_matrix"),
+        pytest.param(list, id="list"),
+    ])
+    def test_invalid_oper_dtype(self, system, oper_dtype):
+        system = _merge_kwargs(system, {"dyn_params": {
+            "oper_dtype": oper_dtype,
+        }})
+        with pytest.raises(ValueError) as err:
+            _optimize_pulse(system)
+        assert str(err.value) == (
+            f"Unknown oper_dtype {oper_dtype!r}. The oper_dtype may be"
+            " qutip.Qobj or numpy.ndarray."
+        )
+
     def test_object_oriented_approach_and_gradient(self, system, propagation):
         """
         Test the object-oriented version of the optimiser, and ensure that the
